<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage  Onjob
 * @since  Onjob 1.0.0
 */

$options = onjob_get_theme_options();  


if ( ! function_exists( 'onjob_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  Onjob 1.0.0
	 */
	function onjob_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'onjob_doctype', 'onjob_doctype', 10 );


if ( ! function_exists( 'onjob_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'onjob_before_wp_head', 'onjob_head', 10 );

if ( ! function_exists( 'onjob_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'onjob' ); ?></a>
		<?php
	}
endif;
add_action( 'onjob_page_start_action', 'onjob_page_start', 10 );

if ( ! function_exists( 'onjob_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'onjob_page_end_action', 'onjob_page_end', 10 );

if ( ! function_exists( 'onjob_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_site_branding() {
		$options  = onjob_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	?>

		<div class="menu-overlay"></div>

		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
				<div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo()  ) : ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php endif; 

					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
						<div id="site-identity">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( onjob_is_latest_posts() || onjob_is_frontpage() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->

				<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e('Primary Menu', 'onjob'); ?>">
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="<?php esc_attr_e('Primary Menu', 'onjob'); ?>">
					<?php
						echo onjob_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
						echo onjob_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
					?>	
						<span class="menu-label"><?php esc_html_e('Menu', 'onjob')?></span>		
					</button>
					<?php  
						$search_html= null;
							$search_html = sprintf(
											'<li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div>',
											esc_attr__('Search','onjob'),
											onjob_get_svg( array( 'icon' => 'search' ) ), 
											onjob_get_svg( array( 'icon' => 'close' ) ), 
											get_search_form( $echo = false )
										);
							
						wp_nav_menu( array(
							'theme_location' => 'primary',
							'container' => 'div',
							'menu_class' => 'menu nav-menu',
							'menu_id' => 'primary-menu',
							'echo' => true,
							'fallback_cb' => 'onjob_menu_fallback_cb',
							'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'.$search_html.'</ul>',

						) );
						
					?>
				</nav><!-- #site-navigation -->
			</div><!-- .wrapper -->
		</header><!-- .header-->
<?php 
	}
endif;
add_action( 'onjob_header_action', 'onjob_site_branding', 10 );

if ( ! function_exists( 'onjob_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'onjob_content_start_action', 'onjob_content_start', 10 );

if ( ! function_exists( 'onjob_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Onjob 1.0.0
     *
     */
    function onjob_header_image() {
        if ( onjob_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php onjob_custom_header_banner_title(); ?>
                </header>
                <?php onjob_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'onjob_header_image_action', 'onjob_header_image', 10 );

if ( ! function_exists( 'onjob_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Onjob 1.0.0
	 */
	function onjob_add_breadcrumb() {
		$options = onjob_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( onjob_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * onjob_simple_breadcrumb hook
				 *
				 * @hooked onjob_simple_breadcrumb -  10
				 *
				 */
				do_action( 'onjob_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'onjob_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'onjob_content_end_action', 'onjob_content_end', 10 );

if ( ! function_exists( 'onjob_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_footer_start() {
		$options = onjob_get_theme_options(); ?>

		<footer id="colophon" class="site-footer" role="contentinfo">
			<?php if($options['enable_footer_search']): ?>
			<div class="search-jobs">
                <div class="wrapper page-section">
                    <article>
						<?php if(!empty($options['footer_search_title'])): ?>
							<header class="entry-header">
								<h2 class="entry-title"><?php echo esc_html($options['footer_search_title']); ?></h2>
							</header>
						<?php endif; ?>
						<?php get_search_form(); ?>
                    </article>
                </div>
            </div>
			<?php endif; ?>
		<?php
	}
endif;
add_action( 'onjob_footer', 'onjob_footer_start', 10 );

if ( ! function_exists( 'onjob_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_footer_site_info() {
		$options = onjob_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
        $theme_data = wp_get_theme();
		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info">
                <div class="wrapper">
                    <span>
                    <?php 
	                	echo onjob_santize_allow_tag( $copyright_text ); 
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}

                	?>
                	
					<?php echo esc_html__( ' All Rights Reserved | ', 'onjob' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'onjob' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ?>
					                	
					</span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'onjob_footer', 'onjob_footer_site_info', 40 );

if ( ! function_exists( 'onjob_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Onjob 1.0.0
	 *
	 */
	function onjob_footer_scroll_to_top() {
		$options  = onjob_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo onjob_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'onjob_footer', 'onjob_footer_scroll_to_top', 40 );
